package wx

import (
	"github.com/ArtisanCloud/PowerWeChat/v3/src/kernel"
	"github.com/ArtisanCloud/PowerWeChat/v3/src/miniProgram"
	"github.com/caarlos0/env/v11"
	"github.com/cloudwego/hertz/pkg/common/hlog"
)

type WX struct {
	AppID     string `env:"WX_APPID"`
	AppSecret string `env:"WX_APPSECRET"`
	Address   string `env:"WX_REDIS_ADDRESS"`
	Password  string `env:"WX_REDIS_PASSWORD"`
	DB        int    `env:"WX_REDIS_DB"`
}

// NewWX 初始化默认的微信客户端
func NewWX() *miniProgram.MiniProgram {
	var config WX
	err := env.Parse(&config)
	if err != nil {
		hlog.Fatalf("加载微信客户端配置失败: %v", err)
	}
	mp, _err := miniProgram.NewMiniProgram(&miniProgram.UserConfig{
		AppID:  config.AppID,
		Secret: config.AppSecret,
		Cache: kernel.NewRedisClient(&kernel.UniversalOptions{
			Addrs:    []string{config.Address},
			Password: config.Password,
			DB:       config.DB,
		}),
	})
	if _err != nil {
		hlog.Fatalf("初始化微信客户端失败: %v", _err)
	}
	return mp
}
